from mkpipe.spark import JdbcExtractor

JAR_PACKAGES = ['com.mysql:mysql-connector-j:9.1.0']


class MysqlExtractor(JdbcExtractor, variant='mysql'):
    driver_name = 'mysql'
    driver_jdbc = 'com.mysql.cj.jdbc.Driver'

    def build_jdbc_url(self):
        return (
            f'jdbc:{self.driver_name}://{self.host}:{self.port}/{self.database}'
            f'?user={self.username}&password={self.password}'
        )



from setuptools import setup, find_packages

setup(
    name='mkpipe-extractor-mysql',
    version='0.4.0',
    license='Apache License 2.0',
    packages=find_packages(exclude=['tests', 'scripts', 'deploy', 'install_jars.py']),
    install_requires=['mkpipe'],
    include_package_data=True,
    entry_points={
        'mkpipe.extractors': [
            'mysql = mkpipe_extractor_mysql:MysqlExtractor',
        ],
    },
    description='MySQL extractor for mkpipe.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Metin Karakus',
    author_email='metin_karakus@yahoo.com',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: Apache Software License',
    ],
    python_requires='>=3.8',
)
